@@ -186,11 +186,14 @@ def query_dataframe(engine: Engine, query: str) -> pd.DataFrame:
         return pd.DataFrame()
 
 
-def dataframe_enricher(advanced_metadata: bool, raw_df: pd.DataFrame) -> pd.DataFrame:
+def dataframe_enricher(
+    advanced_metadata: bool, raw_df: pd.DataFrame, add_uploaded_at: bool = True
+) -> pd.DataFrame:
     """
     Enrich a dataframe with metadata and do some cleaning.
     """
-    raw_df["_uploaded_at"] = time()  # Add an uploaded_at column
+    if add_uploaded_at:
+        raw_df["_uploaded_at"] = time()  # Add an uploaded_at column
 
     if advanced_metadata:
         # Add additional metadata from an Airflow scheduler
@@ -220,12 +223,13 @@ def dataframe_uploader(
     schema: str = None,
     advanced_metadata: bool = False,
     if_exists: str = "append",
+    add_uploaded_at: bool = True,
 ) -> None:
     """
     Upload a dataframe, adding in some metadata and cleaning up along the way.
     """
 
-    dataframe_enricher(advanced_metadata, dataframe).to_sql(
+    dataframe_enricher(advanced_metadata, dataframe, add_uploaded_at).to_sql(
         name=table_name,
         con=engine,
         schema=schema,
